/* KallistiOS ##version##
 *
 * rumble2.c
 */

/* This lets you hex edit the integer that will be sent to your
 * rumble pack.
 */

#include <kos.h>
#include <plx/font.h>

extern uint8 romdisk[];
KOS_INIT_FLAGS(INIT_DEFAULT | INIT_MALLOCSTATS);
KOS_INIT_ROMDISK(romdisk);

int main (int argc, char *argv[]) {
	maple_device_t *dev, *purudev;
	cont_state_t *state;
	plx_font_t * fnt;
	plx_fcxt_t * cxt;
	point_t w;
	int i = 0, count = 0;
	uint16 old_buttons = 0, rel_buttons = 0;
	uint32 effect = 0;
	uint8 n[8] = {0,0,0,0,0,0,0,0}; //nibbles
	char s[8][2] = {"","","","","","","",""};

	//if these buttons are pressed, exit
	cont_btn_callback(0, CONT_START | CONT_A | CONT_B | CONT_X | CONT_Y, 
		(void (*)(unsigned char, long  unsigned int))arch_exit);

	pvr_init_defaults();

	fnt = plx_font_load("/rd/axaxax.txf");
	cxt = plx_fcxt_create(fnt, PVR_LIST_TR_POLY);

	pvr_set_bg_color(0.0f, 0.0f, 0.0f);

	while (1) {
		dev = maple_enum_dev(0, 0);
		purudev = maple_enum_dev(0, 2);

		while (!dev) {
			pvr_wait_ready();
			pvr_scene_begin();
			pvr_list_begin(PVR_LIST_OP_POLY);
			pvr_list_begin(PVR_LIST_TR_POLY);

			plx_fcxt_begin(cxt);
			w.x = 40.0f; w.y = 200.0f; w.z = 10.0f;
			plx_fcxt_setpos_pnt(cxt, &w);
			plx_fcxt_draw(cxt, "Please attach a controller to port A!");
			plx_fcxt_end(cxt);

			pvr_scene_finish();

			dev = maple_enum_dev(0, 0);
		}

		while (!purudev) {
			pvr_wait_ready();
			pvr_scene_begin();
			pvr_list_begin(PVR_LIST_OP_POLY);
			pvr_list_begin(PVR_LIST_TR_POLY);

			plx_fcxt_begin(cxt);
			w.x = 40.0f; w.y = 200.0f; w.z = 10.0f;
			plx_fcxt_setpos_pnt(cxt, &w);
			plx_fcxt_draw(cxt, "Please attach a purupuru to slot A-2!");
			plx_fcxt_end(cxt);

			pvr_scene_finish();

			purudev = maple_enum_dev(0, 2);
		}

		pvr_wait_ready();
		pvr_scene_begin();
		pvr_list_begin(PVR_LIST_OP_POLY);
		pvr_list_begin(PVR_LIST_TR_POLY);

		plx_fcxt_begin(cxt);
		w.x = 70.0f; w.y = 70.0f; w.z = 10.0f;
		plx_fcxt_setpos_pnt(cxt, &w);
		plx_fcxt_draw(cxt, "Rumble2 Demo by SinisterTengu");
		w.x += 130; w.y += 120.0f;
		plx_fcxt_setpos_pnt(cxt, &w);
		plx_fcxt_setsize(cxt, 30.0f);
		plx_fcxt_draw(cxt, "0x");
		w.x += 48.0f;
		plx_fcxt_setpos_pnt(cxt, &w);

		count = 0;
		while (count <= 7) {
			if (i == count)
				plx_fcxt_setcolor4f(cxt, 1.0f, 0.9f, 0.9f, 0.0f);
			else 
				plx_fcxt_setcolor4f(cxt, 1.0f, 1.0f, 1.0f, 1.0f);
			sprintf(s[count], "%x", n[count]);
			plx_fcxt_draw(cxt, s[count]);
			count++;
			w.x += 25.0f;
		}

		plx_fcxt_setsize(cxt, 24.0f);
		plx_fcxt_setcolor4f(cxt, 1.0f, 1.0f, 1.0f, 1.0f);
		w.x = 65.0f; w.y += 50.0f;
		plx_fcxt_setpos_pnt(cxt, &w);
		plx_fcxt_draw(cxt, "Press left/right to switch digits.");
		w.y += 25.0f;
		plx_fcxt_setpos_pnt(cxt, &w);
		plx_fcxt_draw(cxt, "Press up/down to change values.");
		w.y += 25.0f;
		plx_fcxt_setpos_pnt(cxt, &w);
		plx_fcxt_draw(cxt, "Press A to start rumble effect.");
		w.y += 25.0f;
		plx_fcxt_setpos_pnt(cxt, &w);
		plx_fcxt_draw(cxt, "Press B to stop rumble effect.");
		plx_fcxt_end(cxt);

		pvr_scene_finish();

		state = (cont_state_t *)maple_dev_status(dev); 
		rel_buttons = (old_buttons ^ state->buttons);	//store buttons that have been released

		if ((state->buttons & CONT_DPAD_LEFT) && (rel_buttons & CONT_DPAD_LEFT)){
			if (i > 0) i--;
		}
		if ((state->buttons & CONT_DPAD_RIGHT) && (rel_buttons & CONT_DPAD_RIGHT)) {
			if (i < 7) i++;
		}
		if ((state->buttons & CONT_DPAD_UP) && (rel_buttons & CONT_DPAD_UP)){
			if (n[i] < 15) n[i]++;
		}
		if ((state->buttons & CONT_DPAD_DOWN) && (rel_buttons & CONT_DPAD_DOWN)) {
			if (n[i] > 0) n[i]--;
		}
		if((state->buttons & CONT_A) && (rel_buttons & CONT_A)) {
			effect = (n[0]<<28)+(n[1]<<24)+(n[2]<<20)+(n[3]<<16)+(n[4]<<12)+(n[5]<<8)+(n[6]<<4)+(n[7]<<0);

			purupuru_rumble(purudev, effect);
			printf("RUMBLE EFFECT: 0x%x!\n", effect);
		}
		if((state->buttons & CONT_B) && (rel_buttons & CONT_B)) {
			purupuru_rumble(purudev, 0x00000000);
			printf("RUMBLE STOPPED!\n");
		}

		old_buttons = state->buttons ;
	}

	return 0;
}

